@@ -1,7 +1,8 @@
-# vim: fileencoding=utf-8 et ts=4 sts=4 sw=4 tw=0 fdm=marker fmr=#{,#}
+# vim: fileencoding=utf-8 et ts=4 sts=4 sw=4 tw=0
 
-from netcall.green import GreenRPCClient, GreenRPCService
-from netcall.utils import get_zmq_classes
+from netcall.utils       import get_zmq_classes
+from netcall.green       import GreenRPCClient, GreenRPCService
+from netcall.concurrency import get_tools
 
 from .base          import BaseCase
 from .client_mixins import ClientBindConnectMixIn
@@ -11,12 +12,14 @@ from .rpc_mixins    import RPCCallsMixIn
 class GreenhouseBase(BaseCase):
 
     def setUp(self):
-        green_env  = 'greenhouse'
-        Context, _ = get_zmq_classes(env=green_env)
+        env = 'greenhouse'
+        Context, _ = get_zmq_classes(env)
 
-        self.context = Context()
-        self.client  = GreenRPCClient(context=self.context, green_env=green_env)
-        self.service = GreenRPCService(context=self.context, green_env=green_env)
+        self.tools    = get_tools(env)
+        self.context  = Context()
+        self.executor = self.tools.Executor(24)
+        self.client   = GreenRPCClient(context=self.context, green_env=env, executor=self.executor)
+        self.service  = GreenRPCService(context=self.context, green_env=env, executor=self.executor)
 
         super(GreenhouseBase, self).setUp()
 
@@ -24,6 +27,7 @@ class GreenhouseBase(BaseCase):
         self.client.shutdown()
         self.service.shutdown()
         self.context.term()
+        self.executor.shutdown(cancel=True)
 
         super(GreenhouseBase, self).tearDown()
 
